Module attribute

Module attribute 

Structs

Attribute
A flattened label entry, field name and value pair.

Enums

AttributeValue
Value stored against a flattened label field name.
JsonConversionError

Traits

AttributeType
For all client facing APIs, we will use the Attribute struct or a HashMap<String, AttributeValue> for representing attrs However, internally, we may want attributes to be stored as integers or some other compact representation. That is defined by AttributeType.