pub struct Attribute { /* private fields */ }Expand description
A flattened label entry, field name and value pair.
Implementations
Sourceimpl Attribute
impl Attribute
Sourcepub fn from_json_value(
field_name: &str,
json_value: &Value,
) -> Result<Self, JsonConversionError>
pub fn from_json_value( field_name: &str, json_value: &Value, ) -> Result<Self, JsonConversionError>
Create a label from a flattened field name and a JSON value.
Objects and arrays are rejected because input is expected to be flattened. Numbers prefer integer first then real.
Sourcepub fn field_name(&self) -> &String
pub fn field_name(&self) -> &String
Field name getter.
Sourcepub fn value(&self) -> &AttributeValue
pub fn value(&self) -> &AttributeValue
Value getter.
Sourcepub fn from_value(
flattened_field_name: impl Into<String>,
value: AttributeValue,
) -> Self
pub fn from_value( flattened_field_name: impl Into<String>, value: AttributeValue, ) -> Self
Builder from explicit parts.