pub enum CompareOp {
Eq(Value),
Ne(Value),
Lt(f64),
Lte(f64),
Gt(f64),
Gte(f64),
}Expand description
Supported comparison operators with type-safe values
Variants
Eq(Value)
Equal comparison, can be used with any value type
Ne(Value)
Not equal comparison, can be used with any value type
Lt(f64)
Less than comparison, only valid for numeric values
Lte(f64)
Less than or equal comparison, only valid for numeric values
Gt(f64)
Greater than comparison, only valid for numeric values
Gte(f64)
Greater than or equal comparison, only valid for numeric values