FilteredQuery

Struct FilteredQuery 

pub struct FilteredQuery<V> { /* private fields */ }
Type that can be used to specify a query with a filter expression. The Readme.md file in the label-filter folder describes the format of the query expression.

Implementations

Source

impl<V> FilteredQuery<V>

pub fn new(query: V, filter_expr: ASTExpr) -> Self