pub struct FilteredQuery<V> { /* private fields */ }Expand description
Type that can be used to specify a query with a filter expression. The Readme.md file in the label-filter folder describes the format of the query expression.
Implementations